@@ -22,11 +22,12 @@ use Dancer::Handler;
 use base 'Exporter';
 
 $AUTHORITY = 'SUKRIA';
-$VERSION   = '1.140';
+$VERSION   = '1.150';
 @EXPORT    = qw(
   any
   before
   cookies
+  config
   content_type
   dance
   debug
@@ -60,6 +61,7 @@ $VERSION   = '1.140';
   status
   template
   true
+  uri_for
   var
   vars
   warning
@@ -70,6 +72,7 @@ $VERSION   = '1.140';
 sub any          { Dancer::Route->add_any(@_) }
 sub before       { Dancer::Route->before_filter(@_) }
 sub cookies      { Dancer::Cookies->cookies }
+sub config       { Dancer::Config::settings() }
 sub content_type { Dancer::Response::content_type(@_) }
 sub debug        { Dancer::Logger->debug(@_) }
 sub dirname      { Dancer::FileUtils::dirname(@_) }
@@ -116,6 +119,7 @@ sub splat    { @{Dancer::SharedData->request->params->{splat}} }
 sub status   { Dancer::Response::status(@_) }
 sub template { Dancer::Helpers::template(@_) }
 sub true     {1}
+sub uri_for  { Dancer::SharedData->request->uri_for(@_) }
 sub var      { Dancer::SharedData->var(@_) }
 sub vars     { Dancer::SharedData->vars }
 sub warning  { Dancer::Logger->warning(@_) }
@@ -155,20 +159,45 @@ __END__
 
 =head1 NAME
 
-Dancer
+Dancer - Lightweight yet powerful web application framework
+
+
+=head1 SYNOPSIS
+
+    #!/usr/bin/perl
+    use Dancer;
+
+    get '/hello/:name' => sub {
+        return "Why, hello there " . params->{name};
+    };
+
+    dance;
+
+The above is a basic but functional web app created with Dancer.  If you want to
+see more examples and get up and running quickly, check out the
+L<Dancer::Cookbook>.
+
 
 =head1 DESCRIPTION
 
 Dancer is a web application framework designed to be as effortless as possible
-for the developer.
+for the developer, taking care of the boring bits as easily as possible, yet
+staying out of your way and letting you get on with writing your code.
 
-Dancer is here to provide the simpliest way for writing a web application.
+Dancer aims to provide the simplest way for writing web applications, and
+offers the flexibility to scale between a very simple lightweight web service
+consisting of a few lines of code in a single file, all the way up to a more
+complex fully-fledged web application with session support, templates for views
+and layouts, etc.
 
-It can be use to write light-weight web services or small standalone web
-applications.
+If you don't want to write CGI scripts by hand, and find Catalyst too big or
+cumbersome for your project, Dancer is what you need.
 
-If you don't want to write a CGI by hand and find Catalyst too big for your
-project, Dancer is what you need.
+Dancer has few pre-requisites, so your Dancer webapps will be easy to deploy.
+
+Dancer apps can be used with a an embedded web server (great for easy testing),
+and can run under PSGI/Plack for easy deployment in a variety of webserver
+environments.
 
 =head1 USAGE
 
@@ -208,11 +237,11 @@ Here are the ones you can use to define your route handlers.
                     requests for each of your GET route handlers).
                     To define a GET action, use the B<get> keyword.
 
-=item B<POST>       The POST method is used to create a ressource on the
+=item B<POST>       The POST method is used to create a resource on the
                     server.
                     To define a POST action, use the B<post> keyword.
 
-=item B<PUT>        The PUT method is used to update an existing ressource.
+=item B<PUT>        The PUT method is used to update an existing resource.
                     To define a PUT action, use the B<put> keyword.
 
 =item B<DELETE>     The DELETE method requests that the origin server delete
@@ -238,7 +267,7 @@ Or even, a route handler that would match any HTTP methods:
 
 =head2 ROUTE HANDLERS
 
-The route action is the code reference declared, it can access parameters through
+The route action is the code reference declared. It can access parameters through
 the `params' keyword, which returns a hashref.
 This hashref is a merge of the route pattern matches and the request params.
 
@@ -442,8 +471,8 @@ as errors when the setting B<warnings> is set to 1.
 =head2 Before filters
 
 Before filters are evaluated before each request within the context of the
-request and can modify the request and response. It's possible to define variable
-that will be accessible in the action blocks with the keyword 'var'.
+request and can modify the request and response. It's possible to define
+variables which will be accessible in the action blocks with the keyword 'var'.
 
     before sub {
         var note => 'Hi there';
@@ -455,6 +484,19 @@ that will be accessible in the action blocks with the keyword 'var'.
         vars->{note}; # 'Hi there'
     };
 
+
+For another example, this can be used along with session support to easily
+give non-logged-in users a login page:
+
+    before sub {
+        if (!session('user') && request->path_info !~ m{^/login}) {
+            # Pass the original path requested along to the handler:
+            var requested_path => request->path_info;
+            request->path_info('/login');
+        }
+    };
+
+
 The request keyword returns the current Dancer::Request object representing the
 incoming request. See the documentation of the L<Dancer::Request> module for details.
 
@@ -479,9 +521,9 @@ like the following:
     logger: 'file'
     layout: 'main'
 
-And then write as many environment file as you like in appdir/environements.
-That way, the good environment config file will be loaded according to the
-running environment (if none specified, it will be 'development').
+And then write as many environment files as you like in appdir/environments.
+That way, the appropriate  environment config file will be loaded according to
+the running environment (if none is specified, it will be 'development').
 
 Note that you can change the running environment using the --environment
 commandline switch.
@@ -492,12 +534,14 @@ file:
     # appdir/environments/development.yml
     log: 'debug'
     access_log: 1
+    show_errors: 1
 
 And in a production one:
 
     # appdir/environments/production.yml
     log: 'warning'
     access_log: 0
+    show_errors: 0
 
 =head2 load
 
@@ -519,6 +563,16 @@ routes files:
 
     load 'login_routes.pl', 'session_routes.pl', 'misc_routes.pl';
 
+=head2 Accessing configuration data
+
+A Dancer application can access the information from its config file easily with
+the config keyword:
+
+    get '/appname' => sub {
+        return "This is " . config->{appname};
+    };
+
+
 =head1 importing just the syntax
 
 If you want to use more complex files hierarchies, you can import just the syntax of Dancer.
@@ -557,11 +611,16 @@ A directory appdir/logs will be created and will host one logfile per
 environment. The log message contains the time it was written, the PID of the
 current process, the message and the caller information (file and line).
 
+To log messages, use the debug, warning and error methods, for instance:
+
+    debug "This is a debug message";
+
+
 =head1 USING TEMPLATES
 
 =head1 VIEWS
 
-It's possible to render the action's content with a template, this is called a
+It's possible to render the action's content with a template; this is called a
 view. The `appdir/views' directory is the place where views are located.
 
 You can change this location by changing the setting 'views', for instance if
@@ -581,13 +640,14 @@ All views must have a '.tt' extension. This may change in the future.
 
 In order to render a view, just call the 'template' keyword at the end of the
 action by giving the view name and the HASHREF of tokens to interpolate in the
-view (note that all the route params are accessible in the view):
+view (note that the request, session and route params are automatically 
+accessible in the view, named request, session and params):
 
     use Dancer;
     use Template;
 
     get '/hello/:name' => sub {
-        template 'hello' => {var => 42};
+        template 'hello' => { number => 42 };
     };
 
 And the appdir/views/hello.tt view can contain the following code:
@@ -596,6 +656,11 @@ And the appdir/views/hello.tt view can contain the following code:
     <head></head>
     <body>
         <h1>Hello <% params.name %></h1>
+        <p>Your lucky number is <% number %></p>
+        <p>You are using <% request.user_agent %></p>
+        <% IF session.user %>
+            <p>You're logged in as <% session.user %></p>
+        <% END %>
     </body>
    </html>
 
@@ -651,7 +716,7 @@ By default, Dancer will automatically detect the mime-types to use for
 the static files accessed.
 
 It's possible to choose specific mime-type per file extensions. For instance,
-we can imagine you want to sever *.foo as a text/foo content, instead of
+we can imagine you want to serve *.foo as a text/foo content, instead of
 text/plain (which would be the content type detected by Dancer if *.foo are
 text files).
 
@@ -661,8 +726,7 @@ This configures the 'text/foo' content type for any file matching '*.foo'.
 
 =head2 STATIC FILE FROM A ROUTE HANDLER
 
-It's possible for a route handler to pass the batton to a static file, like
-the following.
+It's possible for a route handler to send a static file, as follows:
 
     get '/download/*' => sub {
         my $params = shift;
@@ -733,6 +797,10 @@ The following modules are mandatory (Dancer cannot run without them)
 
 =item L<HTTP::Body>
 
+=item L<MIME::Types>
+
+=item L<URI>
+
 =back
 
 The following modules are optional
@@ -755,6 +823,6 @@ terms as Perl itself.
 =head1 SEE ALSO
 
 The concept behind this module comes from the Sinatra ruby project,
-see L<http://www.sinatrarb.com> for details.
+see L<http://www.sinatrarb.com/> for details.
 
 =cut
