@@ -5,6 +5,7 @@ use warnings;
 use Dancer::Object;
 use Dancer::SharedData;
 use HTTP::Body;
+use URI;
 
 use base 'Dancer::Object';
 Dancer::Request->attributes(
@@ -12,7 +13,7 @@ Dancer::Request->attributes(
     # query
     'env',          'path', 'method',
     'content_type', 'content_length',
-    'body',
+    'body',         'path_info',
 
     # http env
     'user_agent',      'host',
@@ -23,11 +24,9 @@ Dancer::Request->attributes(
 );
 
 # aliases
-sub agent { $_[0]->user_agent }
-
-sub remote_address {
-    $_[0]->env->{'X_FORWARDED_FOR'} || $_[0]->env->{'REMOTE_ADDR'};
-}
+sub agent                 { $_[0]->user_agent }
+sub remote_address        { $_[0]->env->{'REMOTE_ADDR'} }
+sub forwarded_for_address { $_[0]->env->{'X_FORWARDED_FOR'} }
 
 sub new {
     my ($class, $env) = @_;
@@ -69,10 +68,40 @@ sub new_for_request {
     return $req;
 }
 
+sub base {
+    my $self = shift;
+
+    my @env_names = qw(
+        SERVER_NAME HTTP_HOST SERVER_PORT SCRIPT_NAME psgi.url_scheme
+    );
+
+    my ($server, $host, $port, $path, $scheme) = @{$self->env}{@env_names};
+
+    my $uri = URI->new;
+    $uri->scheme($scheme);
+    $uri->authority($host || "$server:$port");
+    $uri->path($path || '/');
+
+    return $uri->canonical;
+}
+
+sub uri_for {
+    my ($self, $part, $params) = @_;
+    my $uri = $self->base;
+
+    # Make sure there's exactly one slash between the base and the new part
+    my $base = $uri->path;
+    $base =~ s|/$||;
+    $part =~ s|^/||;
+    $uri->path("$base/$part");
+
+    $uri->query_form($params) if $params;
+    return $uri->canonical;
+}
+
 # public interface compat with CGI.pm objects (FIXME do Dancer's users really
 # need that compat layer? ) Not sure...
 sub request_method { method(@_) }
-sub path_info      { path(@_) }
 sub Vars           { params(@_) }
 sub input_handle   { $_[0]->{env}->{'psgi.input'} }
 
@@ -103,8 +132,9 @@ sub params {
 sub _init {
     my ($self) = @_;
 
-    $self->_build_path()   unless $self->path;
-    $self->_build_method() unless $self->method;
+    $self->_build_path()      unless $self->path;
+    $self->_build_method()    unless $self->method;
+    $self->_build_path_info() unless $self->path_info;
     $self->_build_request_env();
 
     $self->{_http_body} =
@@ -167,6 +197,19 @@ sub _build_path {
     $self->{path} = $path;
 }
 
+sub _build_path_info {
+    my ($self) = @_;
+    my $info = $self->env->{'PATH_INFO'};
+    if (defined $info) {
+        # Empty path info will be interpreted as "root".
+        $info ||= '/';
+    }
+    else {
+        $info = $self->path;
+    }
+    $self->{path_info} = $info;
+}
+
 sub _build_method {
     my ($self) = @_;
     $self->{method} = $self->env->{REQUEST_METHOD}
@@ -301,6 +344,17 @@ Return the HTTP method used by the client to access the application.
 
 Return the path requested by the client.
 
+=head2 base()
+
+Returns an absolute URI for the base of the application
+
+=head2 uri_for(path, params)
+
+Constructs a URI from the base and the passed path.  If params (hashref) is
+supplied, these are added to the query string of the uri.  If the base is
+C<http://localhost:5000/foo>, C<< request->uri_for('/bar', { baz => 'baz' }) >>
+would return C<http://localhost:5000/foo/bar?baz=baz>.
+
 =head2 params($source)
 
 If no source given, return a mixed hashref containing all the parameters that
