@@ -3,7 +3,6 @@ package Dancer::SharedData;
 use strict;
 use warnings;
 
-my $params = {};
 my $vars   = {};
 
 sub vars {$vars}
@@ -14,17 +13,10 @@ sub var {
     return $vars->{$key};
 }
 
-sub params {
-    my ($class, $value) = @_;
-    $params = $value if (@_ == 2);
-    return $params;
-}
-
 my $request;
 sub request { (@_ == 2) ? $request = $_[1] : $request }
 
 sub reset_all {
-    $params = {};
     $vars   = {};
 }
 
