@@ -3,11 +3,15 @@ package TestUtils;
 use base 'Exporter';
 use vars '@EXPORT';
 
+use File::Path qw(mkpath rmtree);
 use Dancer::Request;
-@EXPORT = qw(fake_request http_request write_file get_response_for_request);
+use Dancer::Config 'setting';
+
+@EXPORT =
+  qw(fake_request http_request write_file get_response_for_request clean_tmp_files);
 
 sub fake_request($$) {
-	my ($method, $path) = @_;
+    my ($method, $path) = @_;
     return Dancer::Request->new_for_request($method => $path);
 }
 
@@ -34,4 +38,13 @@ sub get_response_for_request {
     Dancer::Renderer::get_action_response();
 }
 
+sub clean_tmp_files {
+    my $appdir = setting('appdir') || File::Spec->tmpdir();
+    my $logs_dir = File::Spec->catdir($appdir, 'logs');
+    rmtree($logs_dir) if -d $logs_dir;
+
+    my $sessions = setting session_dir;
+    rmtree($sessions) if $sessions && -d $sessions;
+}
+
 'TestUtils';
